Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Compare ¶
Compare accepts a pair of string slices and returns a slice of their comparison -- this is just an itty bitty helper function so you don't need to create a Differ object yourself since it has no real value other than its Compare method.
func UnifiedDiff ¶
UnifiedDiff accepts a and b which can be strings, bytes, or something you can marshal to json and returns a python difflib style diff string or an error (if there is a marshall error).
func UnifiedDiffColorized ¶
UnifiedDiffColorized is the same as UnifiedDiff but instead of the diff symbols (+, -, ?) the line is rewritten with green, red, yellow (respectively) colorization.
Types ¶
Click to show internal directories.
Click to hide internal directories.